Bifrost: Data Structures

Bifrost

Data Structures
Here are the data structures with brief descriptions:
[detail level 12]

C BackwardCDBG | Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object
C CCDBG_Build_opt | This structure inherits from CDBG_Build_opt and introduces only a few new members which are color-related
C CCDBG_Data_t | If data are to be associated with the unitigs of the colored and compacted de Bruijn graph, those data must be wrapped into a class that inherits from the abstract class CCDBG_Data_t
C CDBG_Build_opt | Most members of this structure are parameters for CompactedDBG<U, G>::build(), except for:
C CDBG_Data_t | If data are to be associated with the unitigs of the compacted de Bruijn graph, those data must be wrapped into a class that inherits from the abstract class CDBG_Data_t
C ColoredCDBG | Represent a Colored and Compacted de Bruijn graph
C CompactedDBG | Represent a Compacted de Bruijn graph
C DataAccessor | Interface to access the colors and the data associated with a unitig of a ColoredCDBG
C DataStorage |
C ForwardCDBG | Wrapper for class neighborIterator to iterate over the predecessors of a reference unitig used in a UnitigMap object
C Kmer | Interface to store and manipulate k-mers
C KmerHash |
C neighborIterator | Iterator for the neighbors (predecessors or successors) of a reference unitig used in a UnitigMap object
C Unitig | Represent a unitig which is a vertex of the Compacted de Bruijn graph
▼C UnitigColors | Represent the k-mer color sets of a unitig
C UnitigColors_const_iterator | See UnitigColors::const_iterator
C UnitigColorsHash |
C unitigIterator | Iterator for the unitigs of a Compacted de Bruijn graph
C UnitigMap | Contain all the information for the mapping of a k-mer or a sequence to a unitig of a Compacted de Bruijn graph
C UnitigMapBase | Structure containing the basic information of a unitig mapping
C UnitigMapHash |